package net.knarcraft.knargui;

import org.bukkit.entity.HumanEntity;
import org.bukkit.entity.Player;
import org.bukkit.event.EventHandler;
import org.bukkit.event.Listener;
import org.bukkit.event.inventory.InventoryClickEvent;
import org.bukkit.event.inventory.InventoryCloseEvent;
import org.bukkit.event.player.PlayerQuitEvent;

/**
 * A listener for tracking GUI interaction
 */
@SuppressWarnings("unused")
public class GUIListener implements Listener {

    private final boolean autoDelete;

    /**
     * Instantiates a new GUI listener
     *
     * @param autoDelete <p>Whether to automatically delete closed GUIs. Useful to prevent RAM leaks</p>
     */
    public GUIListener(boolean autoDelete) {
        this.autoDelete = autoDelete;
    }

    @EventHandler
    public void onInventoryClick(InventoryClickEvent event) {
        HumanEntity clicker = event.getWhoClicked();
        //We're not interested in NPCs
        if (!(clicker instanceof Player player)) {
            return;
        }

        AbstractGUI gui = GUIRegistry.getOpenGUI(player);

        //Not our GUI
        if (gui == null) {
            return;
        }

        //Cancel the event to prevent the player from moving or taking items
        event.setCancelled(true);
        GUIAction action = gui.getAction(event.getSlot(), event.getClick());
        if (action != null) {
            action.run(player);
        }
    }

    @EventHandler
    public void onInventoryClose(InventoryCloseEvent event) {
        if (!(event.getPlayer() instanceof Player player)) {
            return;
        }
        GUIRegistry.closeGUI(player, autoDelete);
    }

    @EventHandler
    public void onPlayerQuit(PlayerQuitEvent event) {
        GUIRegistry.closeGUI(event.getPlayer(), autoDelete);
    }

}
