package net.knarcraft.knargui.item;

import org.bukkit.Bukkit;
import org.bukkit.Material;
import org.bukkit.OfflinePlayer;
import org.bukkit.inventory.ItemStack;
import org.bukkit.inventory.meta.SkullMeta;
import org.bukkit.profile.PlayerProfile;

import java.util.UUID;

/**
 * An item factory for generating player head-based icons
 */
@SuppressWarnings("unused")
public class PlayerHeadGUIItemFactory extends AbstractGUIItemFactory<PlayerHeadGUIItemFactory> {

    /**
     * Instantiates a player head gui item factory
     */
    public PlayerHeadGUIItemFactory() {
        super(new ItemStack(Material.PLAYER_HEAD, 1));
        setChild(this);
    }

    /**
     * Uses the head skin from the given player
     *
     * @param player <p>The player whose skin should be used</p>
     * @return <p>The factory. Used for chaining commands</p>
     */
    public PlayerHeadGUIItemFactory useSkin(OfflinePlayer player) {
        return changeItemMeta(SkullMeta.class, (meta) -> meta.setOwningPlayer(player));
    }

    /**
     * Uses the head skin from the given player profile
     *
     * @param playerProfile <p>The player profile whose skin should be used</p>
     * @return <p>The factory. Used for chaining commands</p>
     */
    public PlayerHeadGUIItemFactory useSkin(PlayerProfile playerProfile) {
        return changeItemMeta(SkullMeta.class, (meta) -> meta.setOwnerProfile(playerProfile));
    }

    /**
     * Uses the head skin from the given player UUID
     *
     * @param uuid <p>The UUID of the skin to use</p>
     * @return <p>The factory. Used for chaining commands</p>
     */
    public PlayerHeadGUIItemFactory useSkin(UUID uuid) {
        return useSkin(Bukkit.getOfflinePlayer(uuid));
    }

}
